==> aliyun_python_sdk_dataworks_public-3.3.29-py2.py3-none-any.whl: aliyunsdkdataworks_public/request/v20200518/CheckFileDeploymentRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class CheckFileDeploymentRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'CheckFileDeployment')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_CheckDetailUrl(self):
		return self.get_body_params().get('CheckDetailUrl')

	def set_CheckDetailUrl(self,CheckDetailUrl):
		self.add_body_params('CheckDetailUrl', CheckDetailUrl)

	def get_CheckerInstanceId(self):
		return self.get_body_params().get('CheckerInstanceId')

	def set_CheckerInstanceId(self,CheckerInstanceId):
		self.add_body_params('CheckerInstanceId', CheckerInstanceId)

	def get_Status(self):
		return self.get_body_params().get('Status')

	def set_Status(self,Status):
		self.add_body_params('Status', Status)

==> aliyun_python_sdk_dataworks_public-4.2.4-py2.py3-none-any.whl: aliyunsdkdataworks_public/request/v20200518/CheckFileDeploymentRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class CheckFileDeploymentRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'CheckFileDeployment')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_CheckDetailUrl(self): # String
		return self.get_body_params().get('CheckDetailUrl')

	def set_CheckDetailUrl(self, CheckDetailUrl):  # String
		self.add_body_params('CheckDetailUrl', CheckDetailUrl)
	def get_CheckerInstanceId(self): # String
		return self.get_body_params().get('CheckerInstanceId')

	def set_CheckerInstanceId(self, CheckerInstanceId):  # String
		self.add_body_params('CheckerInstanceId', CheckerInstanceId)
	def get_Status(self): # String
		return self.get_body_params().get('Status')

	def set_Status(self, Status):  # String
		self.add_body_params('Status', Status)
